<?php

namespace Drupal\Tests\commerce_migrate_commerce\Functional\commerce1;

use Drupal\Tests\commerce_migrate\Functional\MigrateUpgradeReviewPageTestBase;

/**
 * Tests migrate upgrade review page for Commerce 1.
 *
 * @group commerce_migrate
 * @group commerce_migrate_commerce1
 */
class MigrateUpgradeReviewPageTest extends MigrateUpgradeReviewPageTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'action',
    'address',
    'commerce',
    'commerce_log',
    'commerce_migrate',
    'commerce_migrate_commerce',
    'commerce_order',
    'commerce_payment',
    'commerce_price',
    'commerce_product',
    'commerce_store',
    'entity',
    'entity_reference_revisions',
    'inline_entity_form',
    'path',
    'path_alias',
    'profile',
    'state_machine',
    'text',
    'views',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->writeSettings([
      'settings' => [
        'migrate_node_migrate_type_classic' => (object) [
          'value' => TRUE,
          'required' => TRUE,
        ],
      ],
    ]);
    $this->loadFixture(drupal_get_path('module', 'commerce_migrate_commerce') . '/tests/fixtures/ck2.php');
  }

  /**
   * {@inheritdoc}
   */
  protected function getSourceBasePath() {
    return __DIR__ . '/files';
  }

  /**
   * {@inheritdoc}
   */
  protected function getAvailablePaths() {
    return [
      'Address Field',
      'Block',
      'Blog',
      'Bulk Export',
      'Chaos Tools (CTools) AJAX Example',
      'Chaos tools',
      'Color',
      'Comment',
      'Commerce',
      'Commerce Message',
      'Contact',
      'Content translation',
      'Contextual links',
      'Custom content panes',
      'Custom rulesets',
      'Customer',
      'Dashboard',
      'Database logging',
      'Date',
      'Date API',
      'Date All Day',
      'Date Context',
      'Date Migration',
      'Date Popup',
      'Date Repeat API',
      'Date Repeat Field',
      'Date Tools',
      'Date Views',
      'Entity API',
      'Entity Reference',
      'Entity feature module',
      'Entity tokens',
      'Field',
      'Field SQL storage',
      'Field UI',
      'File',
      'Filter',
      'Help',
      'Image',
      'Line Item',
      'Link',
      'List',
      'Menu',
      'Node',
      'Number',
      'OpenID',
      'Options',
      'Overlay',
      'PHP filter',
      'Page manager',
      'Path',
      'Poll',
      'Price',
      'Product',
      'Product Reference',
      'Profile',
      'RDF',
      'Search',
      'Search embedded form',
      'Shortcut',
      'Stylizer',
      'Synchronize translations',
      'System',
      'Taxonomy',
      'Term Depth access',
      'Test search node tags',
      'Test search type',
      'Testing',
      'Text',
      'Title',
      'Token',
      'Toolbar',
      'Trigger',
      'User',
      'Views UI',
      'Views content panes',
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getMissingPaths() {
    return [
      'Actions permissions (VBO)',
      'Administration views',
      'Advanced help',
      'Aggregator',
      'Authorize.Net',
      'Basque Services',
      'Block languages',
      'Book',
      'Cart',
      'Checkout',
      'Chosen',
      'Cloud Zoom',
      'Colorbox',
      'Commerce Addressbook',
      'Commerce American Express',
      'Commerce AutoSKU',
      'Commerce Backoffice',
      'Commerce Backoffice Order',
      'Commerce Backoffice Product',
      'Commerce Backoffice content',
      'Commerce Checkout Progress',
      'Commerce Checkout Redirect',
      'Commerce Checkout by Amazon',
      'Commerce Customer Dummy Profile',
      'Commerce Discount',
      'Commerce Extra Price Formatters',
      'Commerce Features',
      'Commerce Kickstart',
      'Commerce Kickstart Block',
      'Commerce Kickstart Blog',
      'Commerce Kickstart Comment',
      'Commerce Kickstart Help',
      'Commerce Kickstart Inline Help',
      'Commerce Kickstart Lite Product',
      'Commerce Kickstart Menus',
      'Commerce Kickstart Merchandising',
      'Commerce Kickstart Migrate',
      'Commerce Kickstart Order',
      'Commerce Kickstart Product',
      'Commerce Kickstart Product UI',
      'Commerce Kickstart Reset',
      'Commerce Kickstart Search',
      'Commerce Kickstart Slideshow',
      'Commerce Kickstart Social',
      'Commerce Kickstart Taxonomy',
      'Commerce Kickstart User',
      'Commerce Login and Pay with Amazon',
      'Commerce Migrate',
      'Commerce Moneybookers',
      'Commerce Moneybookers Quick Checkout',
      'Commerce PayLeap',
      'Commerce Paymill',
      'Commerce Search API',
      'Commerce UI',
      'Commerce Yotpo',
      'Commerce add to cart confirmation',
      'Commerce fancy attributes',
      'Commerce payment offsite test',
      'Connector',
      'Connector Action Default Register Form',
      'Contact translation',
      'Countries',
      'Countries configuration',
      'Countries translation',
      'Crumbs',
      'Current Search Blocks',
      'Customer UI',
      'Database search',
      'Distribution Update Status Manager',
      'Dutch Services',
      'Eva',
      'Exactor API',
      'Exactor AVS',
      'Exactor Calculation Services',
      'Exactor EUC',
      'Facet API',
      'Farsi Services',
      'Favorite Services',
      'Features',
      'Features Override',
      'Fences',
      'Field Extractor',
      'Field translation',
      'First Data Global Gateway e4',
      'First Data Global Gateway e4 Hosted Payment Pages',
      'First Data Global Gateway e4 Web Service',
      'Flat Rate',
      'Forum',
      'Forward Services',
      'General Services',
      'German Services',
      'Hosted PCI',
      'Http Client',
      'Http Client OAuth',
      'Hungarian Services',
      'Image Delta Formatter',
      'Inline Conditions',
      'Inline Entity Form',
      'Internationalization',
      'Italian Services',
      'Kameleoon',
      'Kiala',
      'Kiala Pack & Ship Integration',
      'Kiala Track & Trace Integration',
      'Libraries',
      'Line Item UI',
      'Lingotek Translation',
      'Locale',
      'Mail System',
      'MailUp',
      'MailUp Subscribe',
      'Mailjet',
      'Mailjet Campaigns',
      'Mailjet Event API',
      'Mailjet Lists',
      'Mailjet Stats',
      'Mailjet subscription',
      'Menu attributes',
      'Menu translation',
      'Message',
      'Message notify',
      'Migrate',
      'Migrate Extras',
      'Migrate Extras Media',
      'Migrate Extras Pathauto Example',
      'Migrate Extras Profile2 Example',
      'Migrate UI',
      'Mime Mail',
      'Mime Mail Action',
      'Mime Mail CSS Compressor',
      'Module filter',
      'Multilingual content',
      'Multilingual forum',
      'Multilingual select',
      'Nosto Tagging',
      'OAuth',
      'OAuth Connector',
      'OAuth Provider UI',
      'OAuth2',
      'Order',
      'Order UI',
      'Path translation',
      'Pathauto',
      'PayPal',
      'PayPal Checkout',
      'PayPal Express Checkout',
      'PayPal Payments Advanced and Payflow Link',
      'PayPal WPP',
      'PayPal WPS',
      'Payment',
      'Payment Method Example',
      'Payment UI',
      'Physical Fields',
      'Physical Product',
      'Polish Services',
      'Print Services',
      'Product Pricing',
      'Product Pricing UI',
      'Product UI',
      'Remote Stream Wrapper',
      'Rules',
      'Rules Scheduler',
      'Rules UI',
      'Rules translation',
      'Russian Services',
      'Search API',
      'Search API sorts',
      'Search Facets',
      'Search Views',
      'Search ranges',
      'Service Links Displays',
      'Service Links Sprites',
      'Service links',
      'Shipping',
      'Shipping UI',
      'Spanish Services',
      'Special menu items',
      'Statistics',
      'String translation',
      'Strongarm',
      'Swedish Services',
      'Syslog',
      'Tax',
      'Tax UI',
      'Taxonomy menu',
      'Taxonomy translation',
      'Toolbar Megamenu',
      'Tracker',
      'Translation redirect',
      'Translation sets',
      'Update manager',
      'User mail translation',
      'Variable',
      'Variable admin',
      'Variable realm',
      'Variable store',
      'Variable translation',
      'Variable views',
      'Views',
      'Views Bulk Operations',
      'Views megarow',
      'Widget Services',
      'Yottaa',
      'migrate_status_active_test',
    ];
  }

}
